@@ -1,3 +1,20 @@
+/*	Copyright (C) 1997 Marius Vollmer
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this software; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #ifndef GUILE_GTK_H
 #define GUILE_GTK_H
 
@@ -58,10 +75,13 @@ void sgtk_callback_destroy (gpointer data);
 SCM sgtk_arg2scm (GtkArg *a);
 void sgtk_scm2arg (GtkArg *a, SCM obj);
 
-void sgtk_init (int *argcp, char ***argvp);
-
 SCM sgtk_color_conversion (SCM color);
 SCM sgtk_font_conversion (SCM color);
+SCM sgtk_string_conversion (SCM string);
+
+void sgtk_init (int *argcp, char ***argvp);
+void sgtk_init_argv (int argc, char **argv);
+void scm_init_toolkits_gtkstubs_module ();
 
 /* emergency fixes */
 typedef int GtkWidgetFlags;
