@@ -5,9 +5,9 @@
  *
  * Authors: Miguel de Icaza
 
-   This program is g_free software; you can redistribute it and/or modify
+   This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the G_Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
@@ -18,36 +18,7 @@
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the G_Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-   DOC: gnome configuration routines.
-   
-   All of the routines receive a pathname, the pathname has the following
-   form:
-
-        /filename/section/key[=default]
-
-   This format reprensents: a filename relative to the Gnome config
-   directory called filename (ie, ~/.gnome/filename), in that file there
-   is a section called [section] and key is the left handed side of the
-   values.
-
-   If default is provided, it cane be used to return a default value
-   if none is specified on the config file.
-
-   Examples:
-   
-   /gmix/Balance/Ratio=0.5
-   /filemanager/Panel Display/html=1
-
-   If the pathname starts with '=', then instead of being a ~/.gnome relative
-   file, it is an abolute pathname, example:
-
-   =/home/miguel/.mc.ini=/Left Panel/reverse=1
-
-   This reprensents the config file: /home/miguel/.mc.ini, section [Left Panel],
-   variable reverse.
-   
-   */
+*/
 
 /* #include <config.h> */
 #include <stdio.h>
@@ -97,11 +68,21 @@ typedef struct {
 	char *path, *opath;
 } ParsedPath;
 
+struct _prefix_list {
+	char *p_prefix;
+	struct _prefix_list *p_back;
+};
+
+typedef struct _prefix_list prefix_list_t;
+
 /*
  * Prefix for all the configuration operations
  * iff the path does not begin with / or with #
  */
-static char *prefix;
+
+#define prefix (prefix_list ? prefix_list->p_prefix : NULL)
+
+static prefix_list_t *prefix_list;
 
 static TProfile *Current = 0;
 
@@ -118,7 +99,7 @@ release_path (ParsedPath *p)
 }
 
 static ParsedPath *
-parse_path (char *path)
+parse_path (const char *path)
 {
 	ParsedPath *p = g_malloc (sizeof (ParsedPath));
 	char *sep;
@@ -131,28 +112,56 @@ parse_path (char *path)
 		p->opath = g_copy_strings (prefix, path, NULL);
 
 	p->path = p->opath;
-	
-	if (*p->path == '='){
-		sep = "=";
-		p->path++;
-	} else
-		sep = "/=";
-	
-	p->file    = strtok (p->path, sep);
-	p->section = strtok (NULL, "/=");
-	p->key     = strtok (NULL, "=");
-	p->def     = strtok (NULL, "=");
 
-	/* Was it a Gnome-relative pathname? */
-	if (*sep == '/'){
-		char *f = g_concat_dir_and_file (gnome_user_dir, p->file);
-		p->file = f;
+	if (*p->path == '='){
+		/* If it is an absolute path name */
+		p->path++;
+		p->file    = strtok (p->path, "=");
+		p->section = strtok (NULL, "/=");
+		p->key     = strtok (NULL, "=");
+		p->def     = strtok (NULL, "=");
+	} else {
+		char *end;
+		sep = "/=";
+
+		p->file    = p->path;
+		p->def     = NULL;
+		p->section = NULL;
+		p->key     = NULL;
+		if (end = strchr (p->path, '=')){
+			*end = 0;
+			p->def = end + 1;
+		} else 
+			end = p->path + strlen (p->path);
+
+		/* Look backwards for a slash, to split key from the filename/section */
+		while (end > p->path){
+			end--;
+			if (*end == '/'){
+				*end = 0;
+				p->key = end + 1;
+				break;
+			}
+		}
+
+		/* Look backwards for the next slash, to get the section name */
+		while (end > p->path){
+			end--;
+			if (*end == '/'){
+				*end = 0;
+				p->section = end + 1;
+				break;
+			}
+		}
+		if (*p->file == '/')
+			p->file++;
+		p->file = g_concat_dir_and_file (gnome_user_dir, p->file);
 	}
 	return p;
 }
 
 static int 
-is_loaded (char *filename, TSecHeader **section)
+is_loaded (const char *filename, TSecHeader **section)
 {
 	TProfile *p = Base;
 	
@@ -167,8 +176,72 @@ is_loaded (char *filename, TSecHeader **section)
 	return 0;
 }
 
+static char *
+decode_string_and_dup (char *s)
+{
+	char *p = g_malloc (strlen (s) + 1);
+	char *q = p;
+
+	do {
+		if (*s == '\\'){
+			switch (*(++s)){
+			case 'n':
+				*p++ = '\n';
+				break;
+			case '\\':
+				*p++ = '\\';
+				break;
+			case 'r':
+				*p++ = '\r';
+				break;
+			default:
+				*p++ = '\\';
+				*p++ = *s;
+			}
+		} else
+			*p++ = *s;
+	} while (*s++);
+	return q;
+}
+
+static char *
+escape_string_and_dup (char *s)
+{
+	char *return_value, *p = s;
+	int len = 0;
+	
+	while (*p){
+		len++;
+		if (*p == '\n' || *p == '\\' || *p == '\r' || *p == '\0')
+			len++;
+		p++;
+	}
+	return_value = p = (char *) g_malloc (len + 1);
+	if (!return_value)
+		return 0;
+	do {
+		switch (*s){
+		case '\n':
+			*p++ = '\\';
+			*p++ = 'n';
+			break;
+		case '\r':
+			*p++ = '\\';
+			*p++ = 'r';
+			break;
+		case '\\':
+			*p++ = '\\';
+			*p++ = '\\';
+			break;
+		default:
+			*p++ = *s;
+		}
+	} while (*s++);
+	return return_value;
+}
+
 static TSecHeader *
-load (char *file)
+load (const char *file)
 {
 	FILE *f;
 	int state;
@@ -247,7 +320,7 @@ load (char *file)
 		case KeyValue:
 			if (overflow || c == '\n'){
 				*next = '\0';
-				SecHeader->keys->value = strdup (CharBuffer);
+				SecHeader->keys->value = decode_string_and_dup (CharBuffer);
 				state = c == '\n' ? KeyDef : IgnoreToEOL;
 				next = CharBuffer;
 #ifdef DEBUG
@@ -263,14 +336,14 @@ load (char *file)
 	} /* while ((c = getc (f)) != EOF) */
 	if (c == EOF && state == KeyValue){
 		*next = '\0';
-		SecHeader->keys->value = strdup (CharBuffer);
+		SecHeader->keys->value = decode_string_and_dup (CharBuffer);
 	}
 	fclose (f);
 	return SecHeader;
 }
 
 static void 
-new_key (TSecHeader *section, char *key_name, char *value)
+new_key (TSecHeader *section, const char *key_name, const char *value)
 {
 	TKeys *key;
     
@@ -281,9 +354,10 @@ new_key (TSecHeader *section, char *key_name, char *value)
 	section->keys = key;
 }
 
-static char *
-access_config (access_type mode, char *section_name, char *key_name, 
-		   char *def, char *filename, int *def_used)
+static const char *
+access_config (access_type mode, const char *section_name,
+	       const char *key_name, const char *def, const char *filename,
+	       int *def_used)
 {
     
 	TProfile   *New;
@@ -346,8 +420,11 @@ dump_keys (FILE *profile, TKeys *p)
 	if (!p)
 		return;
 	dump_keys (profile, p->link);
-	if (*p->key_name) 
-		fprintf (profile, "%s=%s\n", p->key_name, p->value);
+	if (*p->key_name) {
+		char *t = escape_string_and_dup (p->value);
+		fprintf (profile, "%s=%s\n", p->key_name, t);
+		free (t);
+	}
 }
 
 static void 
@@ -424,7 +501,7 @@ free_profile (TProfile *p)
 }
 
 void 
-gnome_config_clean_file (char *path)
+gnome_config_clean_file (const char *path)
 {
 	TProfile *p;
 	ParsedPath *pp;
@@ -448,7 +525,7 @@ gnome_config_clean_file (char *path)
 }
 
 void *
-gnome_config_init_iterator (char *path)
+gnome_config_init_iterator (const char *path)
 {
 	TProfile   *New;
 	TSecHeader *section;
@@ -488,7 +565,7 @@ gnome_config_iterator_next (void *s, char **key, char **value)
 }
 
 void 
-gnome_config_clean_section (char *path)
+gnome_config_clean_section (const char *path)
 	/* *section_name, char *file */
 {
 	TSecHeader *section;
@@ -514,7 +591,7 @@ gnome_config_clean_section (char *path)
 }
 
 void 
-gnome_config_clean_key (char *path)
+gnome_config_clean_key (const char *path)
 	/* *section_name, char *file */
 {
 	TSecHeader *section;
@@ -542,7 +619,7 @@ gnome_config_clean_key (char *path)
 }
 
 int 
-gnome_config_has_section (char *path)
+gnome_config_has_section (const char *path)
 	/* char *section_name, char *profile */
 {
 	TSecHeader *section;
@@ -571,10 +648,10 @@ gnome_config_drop_all (void)
 }
 
 int
-gnome_config_get_int_with_default (char *path, int *def)
+gnome_config_get_int_with_default (const char *path, int *def)
 {
 	ParsedPath *pp;
-	char *r;
+	const char *r;
 	int  v;
 	
 	pp = parse_path (path);
@@ -589,25 +666,26 @@ gnome_config_get_int_with_default (char *path, int *def)
 }
 
 char *
-gnome_config_get_string_with_default (char *path, int *def)
+gnome_config_get_string_with_default (const char *path, int *def)
 {
 	ParsedPath *pp;
-	char *r;
+	const char *r;
+	char *ret = NULL;
 	
 	pp = parse_path (path);
 	r = access_config (LOOKUP, pp->section, pp->key, pp->def, pp->file,
 			   def);
 	if (r)
-		r = strdup (r);
+		ret = strdup (r);
 	release_path (pp);
-	return r;
+	return ret;
 }
 
 int
-gnome_config_get_bool_with_default (char *path, int *def)
+gnome_config_get_bool_with_default (const char *path, int *def)
 {
 	ParsedPath *pp;
-	char *r;
+	const char *r;
 	int  v;
 	
 	pp = parse_path (path);
@@ -629,10 +707,10 @@ gnome_config_get_bool_with_default (char *path, int *def)
 }
 
 void
-gnome_config_set_string (char *path, char *new_value)
+gnome_config_set_string (const char *path, const char *new_value)
 {
 	ParsedPath *pp;
-	char *r;
+	const char *r;
 	
 	pp = parse_path (path);
 	r = access_config (SET, pp->section, pp->key, new_value, pp->file,
@@ -641,11 +719,11 @@ gnome_config_set_string (char *path, char *new_value)
 }
 
 void
-gnome_config_set_int (char *path, int new_value)
+gnome_config_set_int (const char *path, int new_value)
 {
 	ParsedPath *pp;
 	char intbuf [40];
-	char *r;
+	const char *r;
 	
 	pp = parse_path (path);
 	sprintf (intbuf, "%d", new_value);
@@ -655,10 +733,10 @@ gnome_config_set_int (char *path, int new_value)
 }
 
 void
-gnome_config_set_bool (char *path, int new_value)
+gnome_config_set_bool (const char *path, int new_value)
 {
 	ParsedPath *pp;
-	char *r;
+	const char *r;
 	
 	pp = parse_path (path);
 	r = access_config (SET, pp->section, pp->key,
@@ -667,16 +745,50 @@ gnome_config_set_bool (char *path, int new_value)
 }
 
 void
-gnome_config_set_prefix (char *path)
+gnome_config_push_prefix (const char *path)
 {
-	prefix = strdup (path);
+	prefix_list_t *p = g_malloc (sizeof (prefix_list_t));
+
+	p->p_back = prefix_list;
+	p->p_prefix = strdup (path);
+	prefix_list = p;
 }
 
 void
-gnome_config_drop_prefix (void)
+gnome_config_pop_prefix (void)
 {
-	if (!prefix)
+	prefix_list_t *p = prefix_list;
+	
+	if (!p)
 		return;
-	free (prefix);
-	prefix = 0;
+
+	free (p->p_prefix);
+	prefix_list = p->p_back;
+	free (p);
 }
+
+#ifdef TEST
+x (char *str, char *file, char *sec, char *key, char *val)
+{
+	ParsedPath *pp;
+
+	printf ("%s\n", str);
+	pp = parse_path (str);
+	printf ("   file: %s [%s]\n", pp->file, file);
+	printf ("   sect: %s [%s]\n", pp->section, sec);
+	printf ("   key:  %s [%s]\n", pp->key, key);
+	printf ("   def:  %s [%s]\n", pp->def, val);
+}
+
+main ()
+{
+	gnome_user_dir = "USERDIR";
+	x ("=/tmp/file=seccion/llave=valor", "/tmp/file", "seccion", "llave", "valor");
+	x ("=/tmp/file=seccion/llave", "/tmp/file", "seccion", "llave", NULL);
+	x ("/file/seccion/llave=valor", "USERDIR/file", "seccion", "llave", "valor");
+	x ("/file/seccion/llave", "USERDIR/file", "seccion", "llave", NULL);
+	x ("/file/archivo/archivo/seccion/llave", "USERDIR/file/archivo/archivo", "seccion", "llave", NULL);
+	x ("/file/archivo/archivo/seccion/llave=valor", "USERDIR/file/archivo/archivo", "seccion", "llave", "valor");
+	
+}
+#endif
