@@ -190,10 +190,11 @@ g_concat_dir_and_file (const char *dir, const char *file)
  * 
  */
 
-gchar *gnome_util_user_home(void)
+char *
+gnome_util_user_home(void)
 {
-	static gchar *home_dir;
-	static gint init = 1;
+	static char *home_dir;
+	static int init = 1;
 	
 	if (init) {
 		home_dir = getenv("HOME");
@@ -208,23 +209,23 @@ gchar *gnome_util_user_home(void)
  * /home/imain/.gnome/bookmarks.html
  * 
  * Remember to g_free() returned value! */
-gchar *gnome_util_prepend_user_home(char *file)
+
+char *
+gnome_util_prepend_user_home(char *file)
 {
-	gchar *home_return;
-	home_return = g_malloc (strlen(file) + strlen(gnome_util_user_home()) + 3);
-	
-	sprintf(home_return, "%s/%s", gnome_util_user_home(), file);
-	return(home_return);
+	return g_concat_dir_and_file(gnome_util_user_home(), file);
 }
 
 /* very similar to above, but adds $HOME/.gnome/ to beginning
  * This is meant to be the most useful version.
  */
-gchar *gnome_util_home_file(char *file)
+
+char *
+gnome_util_home_file(char *file)
 {
-	gchar *home_return;
-	home_return = g_malloc (strlen(file) + strlen(gnome_util_user_home()) + 16);
-	
-	sprintf(home_return, "%s/.gnome/%s", gnome_util_user_home(), file);
-	return(home_return);
+	char *path = g_concat_dir_and_file(gnome_util_user_home(), ".gnome");
+	char *ret = g_copy_strings(path, "/", file, NULL);
+
+	g_free(path);
+	return ret;
 }
