@@ -2,13 +2,15 @@
 #define LIBGNOMEUI_H
 
 #include "libgnome/gnome-defs.h"
+#include "libgnomeui/gnome-app.h"
+#include "libgnomeui/gnome-app-helper.h"
 #include "libgnomeui/gnome-actionarea.h"
 #include "libgnomeui/gnome-colors.h"
 #include "libgnomeui/gnome-color-selector.h"
 #include "libgnomeui/gnome-messagebox.h"
 #include "libgnomeui/gnome-pixmap.h"
-#include "libgnomeui/gnome-toolbar.h"
 #include "libgnomeui/gnome-actionarea.h"
+#include "libgnomeui/gtk-clock.h"
 
 BEGIN_GNOME_DECLS
 
