@@ -1,10 +1,15 @@
 #include "obgtk.h"
 
 @implementation Gtk_Entry : Gtk_Widget
+- castGtkEntry:(GtkEntry *) castitem
+{
+  gtkentry = castitem;
+  return [super castGtkWidget:GTK_WIDGET(castitem)];
+}
+
 - init
 {
-  gtkentry = GTK_ENTRY(gtk_entry_new());
-  return [super castGtkWidget:GTK_WIDGET(gtkwidget)];
+  return [self castGtkEntry:GTK_ENTRY(gtk_entry_new())];
 }
 
 - set_text:(gchar *) text
