@@ -3,20 +3,18 @@
 @implementation Gtk_Label
 - castGtkLabel:(GtkLabel *) castitem
 {
-  gtklabel = castitem;
+  gtklabel = GTK_LABEL(castitem);
   return [super castGtkMisc:GTK_MISC(castitem)];
 }
 
 - init
 {
-  objc_error(self, 101, "Gtk_Label: attempt to call \"init\" method on a class requiring parameters for initialization. Use \"initWithLabel\" instead.");
-  return self;
+  return [self initWithLabel:""];
 }
 
 - initWithLabel:(gchar *) str
 {
-  gtklabel = GTK_LABEL(gtk_label_new(str));
-  return [super castGtkMisc:GTK_MISC(gtklabel)];  
+  return [self castGtkLabel:GTK_LABEL(gtk_label_new(str))];
 }
 
 - set:(gchar *) str
