@@ -5,6 +5,13 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkobject.h>
 
+/* Used for various message & callback relaying stuff */
+gint
+obgtk_signal_relay(GtkObject *object,
+		   gpointer data,
+		   gint nparams,
+		   GtkArg *args);
+
 @interface Gtk_Object : Object
 {
 @public
@@ -35,6 +42,9 @@
    occurs */
 - connectObj:(gchar *) signal_name
 	    :(id) signalObject;
+
+- ref;
+- unref;
 @end
 
 #endif /* OBGTK_OBJECT_H */
