@@ -19,14 +19,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <config.h>
+#include <string.h>
 #include "gtkterm.h"
-#include <stdio.h>
-
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkselection.h>
 #include <gdk/gdkkeysyms.h>
-
+#include <stdio.h>
 
 
 /* --- limits & defaults --- */
@@ -682,7 +681,6 @@ gtk_term_draw (GtkWidget    *widget,
   
   g_return_if_fail (widget != NULL);
   g_return_if_fail (GTK_IS_TERM (widget));
-  g_return_if_fail (area != NULL);
   
   term = GTK_TERM (widget);
   
