@@ -1,22 +1,21 @@
-#include <obgtk/obgtk.h>
-#include <gtkled.h>
-@interface GULPApp : Gtk_App
+#include <obgnome/obgnome.h>
+#include <gemvt/gtkled.h>
+
+
+@interface GULPMainWin : Gnome_AppWin
+{
+@public
+   id app;
+}
+- menu_help_about:(id) anobj;
+- menu_file_exit:(id) anobj;
+@end
+
+@interface GULPApp : Gnome_App
 {
 	PrintSystem *printsys;
-	Gtk_Window *mainwin;
+	GULPMainWin *mainwin;
 	Gtk_VBox *vbox;
-	struct {
-		Gtk_MenuBar *menu;
-		Gtk_MenuItem *file, *help;
-		struct {
-			Gtk_Menu *filem;
-			Gtk_MenuItem *exit;
-		} filem;
-		struct {
-			Gtk_Menu *helpm;
-			Gtk_MenuItem *about;
-		} helpm;
-	} menus;
 	Gtk_ScrolledWindow *listscroller;
 	Gtk_List *printerlist;
 	Gtk_ListItem **printers;
@@ -27,7 +26,7 @@
 	struct {
 		struct {
 			Gtk_VBox *page;
-			Gtk_List *joblist;
+			Gtk_CList *joblist;
 			Gtk_ListItem **jobs;
 			Gtk_Button *canceljob;
 		} jobs;
