@@ -52,18 +52,27 @@
 }
 @end
 
-@implementation GULPApp
-- activate:(id) obj
+@implementation GULPMainWin
+- menu_help_about:(id) anobj
 {
-	if (obj == menus.helpm.about)
-		[[[Gtk_MessageBox alloc]
-		 initWithLabel:"Copyright (C) 1997 Elliot Lee. Licensed under the GPL."]
-		run];
-	else
-		printf("Unknown activation\n");
-	return self;
+  [[[Gtk_MessageBox alloc]
+     initWithLabel:"\nGULP\n\n    Copyright (C) 1997 Elliot Lee <sopwith@redhat.com>.    \n\nLicensed under the GPL.\n"]
+    run];
 }
 
+- menu_file_exit:(id) anobj
+{
+  [app quit];
+}
+
+- delete_event:(id) anobj
+{
+  [app quit];
+  return (id)TRUE;
+}
+@end
+
+@implementation GULPApp
 - destroy:(id) obj
 {
 	gtk_main_quit();
@@ -72,6 +81,7 @@
 
 - toggled:(id) obj
 {
+#if 0
 	if (dotogglehandler) {
 		int opstatus = 0;
 		id curprinter = nil;
@@ -113,6 +123,7 @@
 			dotogglehandler = 1;
 		}
 	}
+#endif
 	return self;
 }
 
@@ -120,7 +131,7 @@
 {
 	id curprinter = nil, tmp;
 	int opstatus = 0;
-	
+#if 0	
 	if (printerlist->gtklist->selection)
 		curprinter = gtk_object_get_user_data(printerlist->gtklist->selection->data);
 	
@@ -130,7 +141,7 @@
 	}
 	
 	if (obj == nb.jobs.canceljob){
-		if (nb.jobs.joblist->gtklist->selection){
+		if (nb.jobs.joblist->gtkclist->selection){
 			tmp = gtk_object_get_data(nb.jobs.joblist->gtklist->selection->data,
 						  "gulpJob");
 			[tmp cancel];
@@ -146,12 +157,13 @@
 	
 	if(opstatus)
 		[[[Gtk_MessageBox alloc] initWithLabel:"Operation failed"] run];
-	
+#endif	
 	return self;
 }
 
 - selection_changed:(id) obj
 {
+#if 0
 	if (obj == printerlist){
 		/* We need to redisplay the jobs */
 		id curprinter = nil;
@@ -164,7 +176,7 @@
 		[nb.printops.startstop set_state:[curprinter isStarted]];
 		dotogglehandler = 1;
 	}
-	
+#endif	
 	return self;
 }
 
@@ -174,15 +186,12 @@
 	int i;
 	Printer *newprt;
 	char buf[255];
+
+#if 0
 	if(nb.jobs.joblist->gtklist->selection)
 		[nb.jobs.joblist
 		unselect_child:gtk_object_get_data(nb.jobs.joblist->gtklist->selection->data,"objc_id")];
-	
-	if (nb.jobs.joblist->gtklist->children){
-		for(l = nb.jobs.joblist->gtklist->children; l; l = l->next)
-			[(id)gtk_object_get_data(l->data, "objc_id") free];
-		[nb.jobs.joblist clear_items:0 theEnd:99999];
-	}
+	[[nb.jobs.joblist freeze] clear];
 	
 	if(!printerlist->gtklist->selection)
 		return self;
@@ -193,15 +202,15 @@
 	nb.jobs.jobs = realloc(nb.jobs.jobs, (newprt->numjobs * sizeof(Gtk_List *)));
 	
 	for (i = 0; i < newprt->numjobs; i++){
-		snprintf(buf, sizeof(buf), "%-5d %-10d %-10s %s",
-			 [newprt->jobs[i] getJobID],
-			 [newprt->jobs[i] getJobSize],
-			 [newprt->jobs[i] getJobOwner],
-			 [newprt->jobs[i] getJobFilenames]);
-		nb.jobs.jobs[i] = [[[Gtk_ListItem alloc] initWithLabel:buf] show];
-		[nb.jobs.jobs[i] set_data:"gulpJob" :newprt->jobs[i]];
-		[nb.jobs.joblist add:nb.jobs.jobs[i]];
+	  char *vals[4];
+	  vals[0] = [newprt->jobs[i] getJobID];
+	  vals[1] = [newprt->jobs[i] getJobFilenames];
+	  vals[2] = [newprt->jobs[i] getJobSize];
+	  vals[3] = [newprt->jobs[i] getJobOwner];
+	  [nb.jobs.joblist set_row_data:[nb.jobs.joblist append:vals]
+	     :newprt->jobs[i]];
 	}
+#endif
 	
 	return self;
 }
@@ -211,6 +220,19 @@
 {
 	int i;
 	GList *anitem = NULL;
+	GnomeMenuInfo filemenu[] = {
+	  {GNOME_APP_MENU_ITEM, "Exit", "menu_file_exit", NULL},
+	  {GNOME_APP_MENU_ENDOFINFO, NULL, NULL, NULL}
+	};
+	GnomeMenuInfo helpmenu[] = {
+	  {GNOME_APP_MENU_ITEM, "About", "menu_help_about", NULL},
+	  {GNOME_APP_MENU_ENDOFINFO, NULL, NULL, NULL}
+	};
+	GnomeMenuInfo mainmenu[] = {
+	  {GNOME_APP_MENU_SUBMENU, "File", &filemenu, NULL},
+	  {GNOME_APP_MENU_SUBMENU, "Help", &helpmenu, NULL},	  
+	  {GNOME_APP_MENU_ENDOFINFO, NULL, NULL, NULL}
+	};
 	
 	self = [super initApp:argcp :argvp];
 
@@ -218,37 +240,19 @@
 	printsys = [PrintSystem new];
 	if(![printsys exists]) {
 	    [[[Gtk_MessageBox alloc] initWithLabel:"Printing system not installed"] run];
+	    g_print("Printing system not installed\n");
 	    [printsys free];
 	    [super free];
 	    return nil;
 	}
-	mainwin = [[Gtk_Window alloc] initWithWindowType:GTK_WINDOW_TOPLEVEL];
-	[mainwin set_title:"GNOME Unified Link to Printers"];
+	mainwin = [[GULPMainWin alloc]
+		    initWithAppWinInfo:"gulp" : "GNOME Unified Link to Printers"];
+	mainwin->app = self;
 	vbox = [[[Gtk_VBox alloc] initWithBoxInfo:0 setSpacing:5] show];
-	
-	menus.menu = [[[Gtk_MenuBar alloc] init] show];
-	menus.file = [[[Gtk_MenuItem alloc] initWithLabel:"File"] show];
-	menus.filem.filem = [[Gtk_Menu new] show];
-	menus.filem.exit = [[[Gtk_MenuItem alloc] initWithLabel:"Exit"] show];
-	[menus.filem.exit signal_connect:"activate"
-	signalFunc:(GtkSignalFunc)gtk_exit funcData:0];
 
-	menus.help = [[[Gtk_MenuItem alloc] initWithLabel:"Help"] show];
-	menus.helpm.helpm = [[Gtk_Menu new] show];
-	menus.helpm.about = [[[[Gtk_MenuItem alloc] initWithLabel:"About"] show]
-			    connectObj:"activate" :self];
-  
-	[menus.menu append:menus.file];
-	[menus.menu append:menus.help];
-	[menus.help connectObj:"activate" :self];
-	[menus.filem.filem append:menus.filem.exit];
-	[menus.file set_submenu:menus.filem.filem];
-	[menus.helpm.helpm append:menus.helpm.about];
-	[menus.help set_submenu:menus.helpm.helpm];
+	[mainwin create_menus:mainmenu];
 
-	[vbox pack_start_defaults:menus.menu];
-	[mainwin signal_connect:"destroy"
-	signalFunc:(GtkSignalFunc)gtk_exit funcData:0];
+	[mainwin connect:"delete_event"];
 	printers = malloc(sizeof(Gtk_ListItem *) * printsys->numprinters);
 	leds = malloc(sizeof(Gtk_Misc *) * printsys->numprinters);
 	lbls = malloc(sizeof(Gtk_Label *) * printsys->numprinters);
@@ -277,14 +281,23 @@
 	[vbox pack_start_defaults:printerlist];
 	[vbox pack_start_defaults:[[Gtk_HSeparator new] show]];
   
-	nb.jobs.page = [[[Gtk_VBox alloc] initWithBoxInfo:1 setSpacing:0] show];
-	nb.jobs.joblist = [[Gtk_List new] show];
+	nb.jobs.page = [[[Gtk_VBox alloc] initWithBoxInfo:TRUE setSpacing:0] show];
+	{
+	  char *collist[] = {
+	    "Job ID",
+	    "Filenames",
+	    "Owner",
+	    "Size"
+	  };
+	  nb.jobs.joblist = [[[Gtk_CList alloc] initWithCListInfo:4
+						:collist] show];
+	}
 	nb.jobs.canceljob = [[[[Gtk_Button alloc] initWithLabel:"Cancel"] show]
 			    connectObj:"clicked" :self];
 	[nb.jobs.page add:nb.jobs.joblist];
 	[nb.jobs.page add:nb.jobs.canceljob];
 
-	nb.printops.page = [[[Gtk_HBox alloc] initWithBoxInfo:1 setSpacing:0] show];
+	nb.printops.page = [[[Gtk_HBox alloc] initWithBoxInfo:TRUE setSpacing:0] show];
 	nb.printops.updown = [[[[Gtk_CheckButton alloc] initWithLabel:"Queueing"] show]
 			     connectObj:"toggled" :self];
 	nb.printops.clean = [[[[Gtk_Button alloc] initWithLabel:"Clear Queue"] show]
@@ -296,12 +309,11 @@
 	[nb.printops.page add:nb.printops.updown];
 	[nb.printops.page add:nb.printops.clean];
 	[nb.printops.page add:nb.printops.restart];
-	[nb.printops.page add:nb.printops.startstop];
-       
+	[nb.printops.page add:nb.printops.startstop];       
 
 	[vbox add:nb.printops.page];
 	[vbox add:nb.jobs.page];
-	[mainwin add:vbox];
+	[mainwin set_contents:vbox];
 	[mainwin show];
 	return self;
 }
@@ -310,36 +322,16 @@
 {
 	int i;
 
+#if 0
 	for (i = 0; i < printsys->numprinters; i++) {
-	  [leds[i] free];
-	  [lbls[i] free];
 	  [printers[i] free];
 	}
+#endif
 
 	free(printers);
-	[printerlist free];
-	[mainwin hide];
-	[vbox hide];
-
-	[menus.filem.filem free];
-	[menus.filem.exit free];
-	[menus.file free];
-
-	[menus.help free];
-	[menus.helpm.helpm free];
-	[menus.helpm.about free];
-
-	[menus.menu free];
-
-	[vbox free];
+	g_print("Freeing mainwin\n");
 	[mainwin free];
-
-	[nb.jobs.page free]; [nb.jobs.joblist free]; [nb.jobs.canceljob free];
-	[nb.printops.page free];
-	[nb.printops.updown free];
-	[nb.printops.clean free];
-	[nb.printops.restart free];
-	[nb.printops.startstop free];
+	g_print("Freed mainwin\n");
 	[printsys free];
 
 	return [super free];
@@ -348,13 +340,9 @@
 
 int main(int argc, char *argv[])
 {
-	id myapp;
-	myapp = [GULPApp alloc];
-        [myapp initApp:&argc :&argv];
-	if(myapp != nil) {
-	    [myapp run];
-	    [myapp free];
-	    return 0;
-	} else
-	    return 1;
+	id myapp = [GULPApp alloc];
+	[myapp initApp:&argc :&argv];
+	[myapp run];
+	[myapp free];
+	return 0;
 }
