@@ -153,6 +153,36 @@ create_text_entry(GtkWidget *table, int row, char *label, char *text)
 	return entry;
 }
 
+static void
+check_dentry_save(GnomeDesktopEntry *dentry)
+{
+	FILE *file;
+	char *pruned;
+	char *new_name;
+	char *appsdir;
+
+	file = fopen(dentry->location, "w");
+	if (file) {
+		fclose(file);
+		return;
+	}
+
+	pruned = strrchr(dentry->location, '/');
+	if (pruned)
+		pruned++; /* skip over slash */
+	else
+		pruned = dentry->location;
+
+	appsdir = gnome_util_home_file ("apps");
+	mkdir (appsdir, 0755);
+
+	new_name = g_concat_dir_and_file(appsdir, pruned);
+	g_free(dentry->location);
+	dentry->location = new_name;
+}
+
+#define free_and_nullify(x) { g_free(x); x = NULL; }
+
 static void
 properties_ok_callback(GtkWidget *widget, gpointer data)
 {
@@ -162,12 +192,12 @@ properties_ok_callback(GtkWidget *widget, gpointer data)
 	prop = data;
 	dentry = prop->dentry;
 
-	g_free(dentry->exec);
-	g_free(dentry->tryexec);
-	g_free(dentry->icon_base);
-	g_free(dentry->docpath);
-	g_free(dentry->info);
-	g_free(dentry->type);
+	free_and_nullify(dentry->exec);
+	free_and_nullify(dentry->tryexec);
+	free_and_nullify(dentry->icon_base);
+	free_and_nullify(dentry->docpath);
+	free_and_nullify(dentry->info);
+	free_and_nullify(dentry->type);
 
 	dentry->exec      = g_strdup(gtk_entry_get_text(GTK_ENTRY(prop->execute_entry)));
 	dentry->icon_base = g_strdup(gtk_entry_get_text(GTK_ENTRY(prop->icon_entry)));
@@ -176,11 +206,7 @@ properties_ok_callback(GtkWidget *widget, gpointer data)
 	dentry->type      = g_strdup("Application"); /* FIXME: should handle more cases */
 	dentry->terminal  = GTK_TOGGLE_BUTTON(prop->terminal_toggle)->active;
 
-	/* FIXME: should check for write permission on the file and if
-	 * it is not available, munge the filename (dentry->location)
-	 * so that it ends up in ~/.gnome/apps/Whatever.desktop
-	 */
-
+	check_dentry_save(dentry);
 	gnome_desktop_entry_save(dentry);
 
 	/* FIXME: should update the button and pixmap */
@@ -190,6 +216,8 @@ properties_ok_callback(GtkWidget *widget, gpointer data)
 	g_free(prop);
 }
 
+#undef free_and_nullify
+
 static void
 properties_cancel_callback(GtkWidget *widget, gpointer data)
 {
