@@ -2,6 +2,7 @@
 #define PANEL_H
 
 #include "panel_cmds.h"
+#include "libgnomeui/gnome-session.h"
 
 BEGIN_GNOME_DECLS
 
@@ -50,6 +51,12 @@ void panel_init_applet_modules(void);
 
 gpointer panel_command(PanelCommand *cmd);
 
+int panel_session_save (gpointer client_data,
+			GnomeSaveStyle save_style,
+			int is_shutdown,
+			GnomeInteractStyle interact_style,
+			int is_fast);
+
 
 END_GNOME_DECLS
 
